"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = npmLogin;

var _fs = _interopRequireDefault(require("fs"));

var _path = _interopRequireDefault(require("path"));

var _iniBuilder = _interopRequireDefault(require("ini-builder"));

var _userHome = _interopRequireDefault(require("user-home"));

var _constants = require("../constants");

var _exceptions = require("./exceptions");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function findrc(pathToNpmrc) {
  var userNpmrc = _path.default.join(_userHome.default, '.npmrc');

  if (pathToNpmrc) {
    if (!_fs.default.existsSync(pathToNpmrc)) throw new _exceptions.PathToNpmrcNotExist(pathToNpmrc);

    var stats = _fs.default.statSync(pathToNpmrc);

    if (stats.isFile()) userNpmrc = pathToNpmrc;else userNpmrc = _path.default.join(pathToNpmrc, '.npmrc');
  }

  return userNpmrc;
}

function mergeOrCreateConfig(token, url) {
  var config = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : [];
  var strippedUrl = url.replace(/(^\w+:|^)\/\//, '');

  var iniReg = _iniBuilder.default.find(config, `${_constants.DEFAULT_BINDINGS_PREFIX}:registry`);

  var iniToken = _iniBuilder.default.find(config, `//${strippedUrl}/:_authToken`);

  if (!iniReg) {
    config.push({
      path: [`${_constants.DEFAULT_BINDINGS_PREFIX}:registry`],
      value: url
    });
  } else {
    iniReg.value = url;
  }

  if (!iniToken) {
    config.push({
      path: [`//${strippedUrl}/:_authToken`],
      value: token
    });
  } else {
    iniToken.value = token;
  }

  return config;
}

function npmLogin(token, pathToNpmrc, url) {
  var npmrcPath = findrc(pathToNpmrc);
  var npmrcConfig = _fs.default.existsSync(npmrcPath) ? mergeOrCreateConfig(token, url, _iniBuilder.default.parse(_fs.default.readFileSync(npmrcPath, 'utf-8'))) : mergeOrCreateConfig(token, url);

  try {
    _fs.default.writeFileSync(npmrcPath, _iniBuilder.default.serialize(npmrcConfig));
  } catch (err) {
    throw new _exceptions.WriteToNpmrcError(npmrcPath);
  }

  return npmrcPath;
}
//# sourceMappingURL=registry.js.map